Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(504)

Unified Diff: net/quic/quic_framer.h

Issue 11820005: Largest received -> largest observed. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_connection_test.cc ('k') | net/quic/quic_framer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_framer.h
diff --git a/net/quic/quic_framer.h b/net/quic/quic_framer.h
index 4cda9dcc2a915cf60a0923d903a2ee84272c6afb..f403e14dd06a3f9d2ba6a1ec84dd682c55e152a3 100644
--- a/net/quic/quic_framer.h
+++ b/net/quic/quic_framer.h
@@ -95,10 +95,10 @@ class NET_EXPORT_PRIVATE QuicFramer {
virtual ~QuicFramer();
// Calculates the largest received packet to advertise in the case an Ack
// Frame was truncated. last_written in this case is the iterator for the
// last missing packet which fit in the outgoing ack.
- static QuicPacketSequenceNumber CalculateLargestReceived(
+ static QuicPacketSequenceNumber CalculateLargestObserved(
const SequenceSet& missing_packets,
SequenceSet::const_iterator last_written);
« no previous file with comments | « net/quic/quic_connection_test.cc ('k') | net/quic/quic_framer.cc » ('j') | no next file with comments »
@@ -95,10 +95,10 @@ class NET_EXPORT_PRIVATE QuicFramer {
virtual ~QuicFramer();
- // Calculates the largest received packet to advertise in the case an Ack
+ // Calculates the largest observed packet to advertise in the case an Ack
// Frame was truncated. last_written in this case is the iterator for the
// last missing packet which fit in the outgoing ack.

Powered by Google App Engine
This is Rietveld 408576698